normalizer.StoplistNormalizer

|  | ## Cheshire3 Object Model: Class StoplistNormalizer

Module normalizer :: Class StoplistNormalizer

## Class StoplistNormalizer
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
       baseObjects.Normalizer --+
                                |
                 SimpleNormalizer --+
                                    |
                                   StoplistNormalizer

Remove words that match a stopword list
Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
process_string(self, session, data) Process a string into an alternative form.
Inherited from `SimpleNormalizer`: `process_hash` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

stoplist |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: SimpleNormalizer.__init__

### process_string(self, session, data) | source code
Process a string into an alternative form. Overrides: SimpleNormalizer.process_string

Class Variable Details

    ### stoplist Value:
        {}